[−][src]Crate async_minecraft_ping
Structs
| ConnectionConfig | Builder for a Minecraft ServerListPing connection. |
| ServerDescription | Contains the server's MOTD. |
| ServerPlayer | Contains information about a player. |
| ServerPlayers | Contains information about the currently online players. |
| ServerVersion | Contains information about the server version. |
| StatusConnection | Wraps a built connection |
| StatusResponse | The decoded JSON response from a status query over ServerListPing. |
Enums
| ServerError |
Functions
| connect | Convenience wrapper for easily connecting to a server on the default port with the latest protocol version. |